#
# spec file for package perl-JSON-Validator
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name JSON-Validator
Name:           perl-JSON-Validator
Version:        5.150.0
Release:        1.2
# 5.15 -> normalize -> 5.150.0
%define cpan_version 5.15
License:        Artistic-2.0
Summary:        Validate data against a JSON schema
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JH/JHTHORSEN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(List::Util) >= 1.45
BuildRequires:  perl(Mojolicious) >= 7.280
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::More) >= 1.30
BuildRequires:  perl(YAML::XS) >= 0.670
Requires:       perl(List::Util) >= 1.45
Requires:       perl(Mojolicious) >= 7.280
Requires:       perl(YAML::XS) >= 0.670
Provides:       perl(JSON::Validator) = %{version}
Provides:       perl(JSON::Validator::Error)
Provides:       perl(JSON::Validator::Formats)
Provides:       perl(JSON::Validator::Joi)
Provides:       perl(JSON::Validator::Schema)
Provides:       perl(JSON::Validator::Schema::Draft201909)
Provides:       perl(JSON::Validator::Schema::Draft4)
Provides:       perl(JSON::Validator::Schema::Draft6)
Provides:       perl(JSON::Validator::Schema::Draft7)
Provides:       perl(JSON::Validator::Schema::OpenAPIv2)
Provides:       perl(JSON::Validator::Schema::OpenAPIv3)
Provides:       perl(JSON::Validator::Store)
Provides:       perl(JSON::Validator::URI)
Provides:       perl(JSON::Validator::Util)
%undefine       __perllib_provides
%{perl_requires}

%description
JSON::Validator is a data structure validation library based around at
https://json-schema.org/. This module can be used directly with a JSON
schema or you can use the elegant DSL schema-builder JSON::Validator::Joi
to define the schema programmatically.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md

%changelog
* Mon Mar 17 2025 Tina Müller <timueller+perl@suse.de>
- updated to 5.150.0 (5.15)
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.15 2025-03-16T18:47:47
  - Make JSON::Validator::Util::is_bool return true when passed perl v5.36+ builtin booleans #275
  - Fix wrong resolving of responses component using $ref #277
  - Fix array coercion for array parameters with a $ref schema #274
* Tue Mar  7 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.14
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.14 2023-03-06T13:45:33
  - Avoid mutating OpenAPIv2 schema "parameters" when validating
* Fri Dec  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.13
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.13 2022-12-09T09:55:24
  - Fix not coercing body parameter for OpenAPIv2
* Thu Oct 27 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.12
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.12 2022-10-26T20:14:57
  - Allow unicode strings in the JSON schema #268
    Contributor: Brad Barden
  - Specified Perl version
  - Updated basic repository files
  - Updated contributors list
* Wed Aug 31 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.11
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.11 2022-08-30T15:41:16+0900
  - Fix sorting routes with placeholders on different positions
* Fri Aug 19 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.10
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.10 2022-08-18T07:39:15+0900
  - Add root schema id to "DefaultResponse" to allow external $ref
  5.09 2022-08-17T09:13:55+0900
  - Add support for default collectionFormat when "type" is "array"
* Fri Mar 25 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.08
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.08 2022-03-25T10:00:18+0900
  - Fix handling OpenAPIv2 headers with collectionFormat
  5.07 2022-03-23T07:58:02+0900
  - Fix issues with OpenAPIv3 in 5.06
  5.06 2022-03-23T07:29:23+0900
  - Fix placing OpenAPIv2 bundled path $ref's inside "paths"
* Thu Jan  6 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.05
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.05 2022-01-06T09:33:30+0900
  - Add EXPERIMETNAL support for coercing to array when posting form data
* Fri Dec 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.04
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.04 2021-12-10T07:54:09+0900
  - Fix coercing strings and numbers in schema specification #266
* Sun Nov 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.03
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.03 2021-11-20T13:32:42+0900
  - Fix OpenAPIv3::add_default_response() will not overwrite nested $ref
  - Fix finding "readOnly" and "writeOnly" inside nested $ref
  - Fix joi required() with nested objects
    Contributor: Tim Stallard
* Wed Oct  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.02
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  5.02 2021-10-06T09:58:55+0900
  - Fix defaults for arrays with collectionFormat #263
    Contributor: Ilya Rassadin
  - Improved documentation for JSON::Validator and JSON::Validator::Schema #230
  5.01 2021-10-04T07:13:32+0900
  - Fix registering the correct $ref when bundling
  - Changed get() to resolve $ref #262
  - Deprecated $schema->contains()
  - Deprecated $schema->schema()
  5.00 2021-10-02T10:15:16+0900
  - Validation is much faster
  - Fix "$defs" in draft7 is "definitions"
  - Add benchmark.t to track validation speed
  * Runtime v4.21: 2.62s (n=200)
  * Runtime v5.00: 1.52s (n=200)
  - Add JSON::Validator::Store::resolve()
  - Add JSON::Validator::URI
  - Fix incorrect validation error paths when validating references to same object #244
  - Changed JSON::Validator::Util::is_type()
  * Add JSON::Validator::Util::is_bool()
  * Add JSON::Validator::Util::is_num()
  - Changed bundled definitions/$defs names
  - Changed invalid schema id/$id will not croak
  - Changed internal _validation_xxx() methods to take $state
  - Removed support for bundle({replace => 1}) #194
  - Removed JSON::Validator::OpenAPIv2::allow_invalid_ref()
  - Removed JSON::Validator::Ref
  - Removed JSON::Validator::Util::json_pointer()
  - Removed JSON::Validator::Util::schema_extract()
* Sun Sep 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.25
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.25 2021-09-26T08:41:51+0900
  - Fix checking OpenAPI schema for errors if coerce(defaults) is on #254
  - YAML::XS is preferred instead of YAML::PP #259
  - Cleaned up CPAN distribution files #260
  4.24 2021-09-16T08:02:26+0200
  - Add OpenAPI v3.1.x support
* Sun Aug 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.23
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.23 2021-08-28T16:44:05+0200
  - Fix mishandling of nullable combined witn enum in OpenAPIv3 #256 #257
  4.22 2021-08-27T13:12:56+0200
  - Fix email checking #258
    Contributor: Stephan Hradek
* Sun Jul 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.21
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.21 2021-07-10T15:58:47+0900
  - Fix no warnings when negotiating */* #252
  - Depends on perl v5.16.0 #250
  - Updated x_IRC to irc.libera.chat
* Sat Jun 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.20
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.20 2021-06-18T11:27:02+0900
  - Fix compiling array items #249
  - Fix coerce() will be passed on to schema() objects
  - Add is_invalid() to JSON::Validator::Schema
  - Improved documentation for JSON::Validator and JSON::Validator::Schema
  - Changed joi validator to default to a JSON::Validator::Schema::Draft7 object
  - Deprecated validate(..., $schema)
  - Removed support for coerce(1)
  - Removed support for subclassing JSON::Validator. Need to subclass a schema
    class instead.
  - Simpler inheritance for Schema classes
  4.19 2021-06-17T12:37:10+0900
  - Fix generating correct base_url() object with host and port
  4.18 2021-06-17T11:13:58+0900
  - Fix content_type validation for OpenAPIv2 and OpenAPIv3
  - Fix validating multipart\/form-data with boundary
  - Fix validating content-type with charset
  - Fix parsing OpenAPIv3 spec with "description", "servers" and "summary" in a
    path specifiation.
* Thu Apr 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.17
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.17 2021-04-28T11:30:56+0900
  - Add add_default_response() to OpenAPIv2 and OpenAPIv3
  - Add base_url() to OpenAPIv2 and OpenAPIv3
  - Fix validating "nullable" for "array" and "object"
* Wed Mar 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.16
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.16 2021-03-24T08:57:46+0900
  - Fix handling OpenAPIv2 "responses" $ref when bundling
  4.15 2021-03-24T07:57:58+0900
  - Fix validating nullable inside anyOf for OpenAPIv3 #241
  - Fix t/id-keyword-draft*.t test failures with Mojolicious 9.11 #242 #243
  - Removed deprecated functions joi() and validate_json()
  - Removed deprecated methods singleton() and version()
* Wed Feb 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.14
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.14 2021-02-23T14:58:07+0900
  - Add routes() to Schema::OpenAPIv2 and OpenAPIv3
* Fri Jan 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.13
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.13 2021-01-28T18:22:43+0900
  - Fix handling offset in RFC3339 date-time #236
  - Add CLEAR method to JSON::Validator::Ref #237
* Mon Jan 25 2021 Tina Müller <timueller+perl@suse.de>
- updated to 4.12
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.12 2021-01-25T07:52:34+0900
  - Fix not using Mojo::Exception::raise() #235
  - Fix uninitialized warning when looking up schema for an internal $ref
  4.11 2021-01-24T16:02:02+0900
  - Add JSON::Validator::Schema::OpenAPIv2
  * Extends JSON::Validator::Schema::Draft4
  * Can validate OpenAPIv2 API specifiation
  * Can validate HTTP request and response
  * Can validate "Accept" and "Content-Type"
  * Can handle "discriminator"
  * Can handle "readOnly" parameters
  * Can handle collectionFormat
  * Can handle default values for parameters
  * Can convert specifiation with invalid "$ref" into a valid OpenAPIv2 specifiation
  * Will coerce query parameters and headers into arrays if needed
  - Add JSON::Validator::Schema::OpenAPIv3
  * Extends JSON::Validator::Schema::Draft201909
  * Can validate OpenAPIv3 API specifiation
  * Can validate HTTP request and response
  * Can validate "Accept" and "Content-Type"
  * Can handle "discriminator"
  * Can handle "nullable" parameters
  * Can handle "readOnly" parameters
  * Can handle "style" and "explode" for arrays and objects parameters
  * Can handle "writeOnly" parameters
  * Can handle default values for parameters
  * Will coerce query parameters and headers into arrays if needed
  - Add negotiate_content_type() utility function
  - Fix t/load-file.t on Windows #234
  - Fix not checking if input schema is a file if it has a newline #223 #233
    Contributor: David Cantrell
  - Improved error message when loading non-existing file #231
* Wed Oct 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.10
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.10 2020-10-13T10:53:11+0900
  - Add JSON::Validator::Store
  - Changed JSON::Validator->schema() to also load
  - JSON::Validator->schema() can handle draft 2019-09 schemas
  - Documented what is not supported in draft 2019-09
* Tue Oct 13 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.09
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.09 2020-10-12T11:04:16+0900
  - Fix handling if "id" and "$id" in subschemas #186
  - Add CONTRIBUTING.md #161
  4.08 2020-10-12T08:06:29+0900
  - Implemented basic support for draft 2019-09 #181
  - JSON::Validator::Ref can hold sibling attrs #181
  4.07 2020-10-11T11:48:05+0900
  - Acceptance tests require Test::JSON::Schema::Acceptance 1.000
  4.06 2020-10-10T16:21:51+0900
  - Fix caching of schemas across objects #204 #212
    Contributor: Karen Etheridge
  - Fix "contains" can also be boolean "false"
  - Fix "dependencies" can have boolean subschemas
  - Fix "if" can be false
  - Fix "null" is valid if "pattern" is defined, but no "type"
  - Fix "propertyNames" can be false
  - Fix JSON::Validator::Ref can hold a boolean schema
  - Fix not adding "properties" to the input schema
  - Fix resolving "$ref":"#id"
  - Fix validating data when "additionalItems" is false, but there are enough rules
  - Changed internals of JSON::Validator::Ref
* Tue Oct  6 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.05
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.05 2020-10-06T06:29:31+0900
  - Errors are now reported in a predictable order #223
    Contributor: David Cantrell
* Mon Sep 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.04
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.04 2020-09-28T10:01:58+0900
  - Add "validator" as attribute to JSON::Validator::Joi
  - Changed YAML::XS to an optional module #205
  - Changed column with to be in sync with mojolicious/mojo
  - Fix constructing schema() from correct class
* Tue Sep 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.03
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.03 2020-09-14T18:14:19+0900
  - Add "joi" as exported function to JSON::Validator::Joi
  - Fix SYNOPSIS for JSON::Validator::Joi
* Wed Aug 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.02
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.02 2020-08-11T13:06:40+0900
  - Add recursive_data_protection() #220
    Contributor: Jason Cooper
* Wed Jul  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.01
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.01 2020-06-30T17:42:08+0900
  - Fix combining "allOf" and "not" #218
* Mon Jun  8 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.00
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  4.00 2020-06-08T10:41:55+0900
  - JSON::Validator::schema() now holds a JSON::Validator::Schema object
    instead of Mojo::JSON::Pointer
  - Add schema classes for Draft4, Draft6 and Draft7
  - Add "duration" and "uuid" formats #210
  - Fix coercing boolean "false" #215
  - Fix not matching "null" should also be a "type" error #217
  - Deprecated JSON::Validator::joi()
  - Deprecated JSON::Validator::singleton()
  - Deprecated JSON::Validator::validate_json()
  - Deprecated JSON::Validator::version()
  - Removed JSON::Validator::generate_definitions_path()
  - Removed support for JSON::Validator::bundle({ref_key => ...})
* Thu Mar 26 2020 <timueller+perl@suse.de>
- updated to 3.25
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.25 2020-03-26T07:42:16+0900
  - Made "additionalProperties" error message less confusing
  - Add support for "items" and "contains" can be defined-but-false #207
    Contributor: Karen Etheridge
  - Respect "items" when combined with "contains" #207
    Contributor: Karen Etheridge
  - Require Sereal::Encoder 4.00 to speed up data_checksum()
* Wed Mar  4 2020 <timueller+perl@suse.de>
- updated to 3.24
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.24 2020-03-03T15:46:39+0900
  - Optimize checksum generation #202
    Contributor: Ere Maijala
  - Improved "type":[...] error messages #199
    Contributor: Karen Etheridge
  - Fix handle validation of true, false schemas in oneOf #201 #203
    Contributor: Karen Etheridge
  - Fix guessing type:object if "dependencies" is present #206
* Wed Feb 19 2020 <timueller+perl@suse.de>
- updated to 3.23
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.23 2020-02-19T09:37:44+0900
  - Using List::Util::uniq() instead of JSON::Validator::Util::uniq #198
* Sat Feb 15 2020 <timueller+perl@suse.de>
- updated to 3.22
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.22 2020-02-15T08:35:29+0900
  - Add support for "dependencies" keyword #192 #197
  - Add support for anyOf/allOf/oneOf at the same time #196 #197
  - Allow if/then/else to be in any sort of schema #190 #197
* Fri Feb 14 2020 <timueller+perl@suse.de>
- updated to 3.21
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.21 2020-02-14T10:14:14+0900
  - Fix data_section() without a class #193
* Wed Feb 12 2020 <timueller+perl@suse.de>
- updated to 3.20
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.20 2020-02-12T09:47:21+0900
  - Fix validating draft6 "false" and "true" schemas #190
    Contributor: Karen Etheridge
  - Add JSON::Validator::Util with E(), data_checksum(), data_section(),
    data_type(), is_type(), schema_extract(), json_pointer(),
    prefix_errors(), schema_type() and uniq()
  - Removed support for JSON_VALIDATOR_REPORT
* Sat Feb  8 2020 <timueller+perl@suse.de>
- updated to 3.19
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.19 2020-02-07T11:10:58+0900
  - Add clearer error when more than one oneOf rule matched #184
    Contributor: Karen Etheridge
  - Improved validation of numeric minimum and maximum values
* Wed Jan 29 2020 <timueller+perl@suse.de>
- updated to 3.18
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.18 2020-01-29T10:18:09+0900
  - Fix validating constants that are null or the empty string
    Contributor: Karen Etheridge
* Mon Dec 30 2019 <timueller+perl@suse.de>
- updated to 3.17
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.17 2019-12-29T14:21:53+0900
  - Fix for deep recursion on Windows #170
  - Fix reading unicode specifiation from __DATA__ #179
* Tue Oct 29 2019 <timueller+perl@suse.de>
- updated to 3.16
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.16 2019-10-28T13:59:47+0900
  - Add generate_definitions_path() #175 #177
    Contributor: Henrik Andersen, Jan Henning Thorsen
* Fri Sep 27 2019 <timueller+perl@suse.de>
- updated to 3.15
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.15 2019-09-27T09:28:32+0900
  - Add JSON::Validator::Error->details() #133
  - Reversed the checksum and nice name for generated definitions #173
* Sat Aug 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.14
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.14 2019-08-09T23:52:24+0200
  - Fix failing tests #169
* Fri Aug  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.13
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.13 2019-08-08T16:27:29+0200
  - Fix extend() should not mutate the source objects #167
  3.12 2019-08-08T12:02:14+0200
  - Fix bug: Joi->extend(...) will also merge "required" #166
  - Fix deprecation warning from $joi->validate #165
    Contributor: Mattias Päivärinta
  - Fix loading Time::Local in the correct module #163
    Contributor: Bernhard Graf
* Wed May  8 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.11
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.11 2019-05-07T21:53:16+0700
  - Bundle https://github.com/OAI/OpenAPI-Specification/blob/master/schemas/v3.0/schema.json #157
* Mon May  6 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.10
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.10 2019-05-05T14:32:15+0700
  - Should not add "/definitions" to bundle, if there are no definitions
  - A bit too soon to deprecate bundle({replace => 1}) in 3.09
* Sun May  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.09
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.09 2019-05-04T22:28:55+0700
  - Prettier definition names from bundle().
  - Changed default bundle() definitions location from "x-bundle" to "definitions".
  - Deprecated bundle({ref_ref => ...})
  - Deprecated bundle({replace => ...})
* Sun Apr  7 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.08
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.08 2019-04-06T15:07:11+0700
  - Add support for "default" in object definitions #155
  - Add support for coerce("bool,def,num,str") as alternative to hash
  - Add support for setting coerce in new()
  - Deprecated support for coerce(1)
* Fri Apr  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.07
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.07 2019-04-04T23:43:55+0700
  - Fix not leaking file names with bundle()
* Fri Feb 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.06
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
  3.06 2019-02-14T18:24:29+0100
  - Fix coercing integers and numbers #147
  - Changed recursion guard to not keeping tracking of plain scalars #147
* Fri Feb  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.05
  see /usr/share/doc/packages/perl-JSON-Validator/Changes
* Wed Jan 30 2019 Christian Dywan <cdywan@suse.de>
- Add missing BuildRequires for tests
- Skip failing id-keyword-draft4.t
